==> organic-angel-0.3.1.tgz: package/docs/api.md <==
## Scripts and Abilities syntax

    module.exports = function(angel [, next]) {
      // next is optional, if async loading is needed.
      angel.on(pattern, function(angel [, next]){
        // possibly call next(/* Error, Result optional */)
      })
    }

## Angel API

### angel.dna

property having DNA instance related to Angel itself

#### angel DNA source list

* path.join(process.cwd(), "dna", "angel.json"),
* path.join(process.cwd(), "dna", "angel"),
* path.join(process.cwd(), "angel.json"),
* path.join(home(), "angel.json"),
* path.join(home(), "angel", "dna")

### angel.autoloadDNA(handler)

uses angel DNA source list to populate `angel.dna`  property

### angel.start(handler)

1. autoloads `angel.dna`
2. constructs Nucleus providing organelles build support
3. autoloads angel modules from `process.cwd() + '/node_modules'` folder

### angel.clone()

Returns cloned object of Angel instance keeping references to:

* `angel.reactor`
* `angel.scripts` loader
* `angel.abilities` loader

### angel.on(pattern, handler)

* `pattern` : String with placeholders like 'echo :value' or RegExp
* `handler` : `function(angel, next)`, where
  * `angel` : cloned Angel Object with `cmdData`
    * `cmdData` : Object containing the resulted match of `pattern`
  * `next` : optional `function(err, result)`

* Returns `microApi` instance

Example:

    angel.on("tell me about :topic in :section", function(angel){
      console.log("You asked about topic:"+angel.cmdData.topic)
      console.log("And section:"+angel.cmdData.section)
    })

    // or

    angel.on(/tell me about (.*)/, function(angel){
      console.log("You asked about "+angel.cmdData[1])
    })

### angel.off(microApiInstance)

`handler` won't be fired for `pattern` used in `angel.on` or `angel.once`

### angel.do(command [, handler])

* `command` : String like 'echo test'
* `handler` : `function(err, result)`

#### angel.addDefaultHandler(handler)

Adds a default handler, will be invoked if none handler matched given `angel.do` input command

* `handler` : Function (input: String, done: Callback)

#### .loadScript(scriptPath, handler)
Either `angel.scripts` or `angel.abilities`
Note that scripts receive a clone of `angel` instance.

Load script at given path using the following detect array:

* scriptPath,
* path.join(process.cwd(), scriptPath),
* path.join(process.cwd(), "node_modules", scriptPath),
* path.join(home(), "angel", scriptPath),
* path.join(home(), "angel", "scripts", scriptPath)

### .loadScripts(scriptsArray [, handler])
Either `angel.scripts` or `angel.abilities`
Note that all scripts receive a clone of `angel` instance.

* `scriptsArray` : Array of strings which are paths to scripts.
* `handler` : optional `function(err)`, called once all scripts are loaded.

#### .loadScriptsByPath(directoryPath [, handler])
Either `angel.scripts` or `angel.abilities`
Note that all scripts receive a clone of `angel` instance.

* `directoryPath` : path to a directory containing `.js` files to be loaded
* `handler` : optional `function(err)`, called once all scripts are loaded.

==> organic-angel-0.5.3.tgz: package/docs/api.md <==
## Scripts and Abilities syntax

    module.exports = async function(angel) {
      angel.on(pattern, async function(angel){
      })
    }

## Angel API

### async angel.start()

1. autoloads angel modules from `process.cwd() + '/node_modules'` folder

### angel.clone()

Returns cloned object of Angel instance keeping references to:

* `angel.reactor`
* `angel.plasma`
* `angel.env.cwd`

### async angel.loadDepModules(deps, startingWith, context)

### async angel.loadScript(script, context)

### async angel.loadScripts(script, context)

### angel.on(pattern, handler)

* `pattern` : String with placeholders like 'echo :value' or RegExp
* `handler` : `async function(angel)`, where
  * `angel` : cloned Angel Object with `cmdData`
    * `cmdData` : Object containing the resulted match of `pattern`

* Returns `microApi` instance

Example:

    angel.on("tell me about :topic in :section", function(angel){
      console.log("You asked about topic:"+angel.cmdData.topic)
      console.log("And section:"+angel.cmdData.section)
    })

    // or

    angel.on(/tell me about (.*)/, function(angel){
      console.log("You asked about "+angel.cmdData[1])
    })

### angel.once(pattern, handler)

Same as `angel.on` but will handle the pattern only once.

### angel.off(microApiInstance)

`handler` won't be fired for `pattern` used in `angel.on` or `angel.once`

### async angel.do(command)

* `command` : String like 'echo test'

#### angel.addDefaultHandler(handler)

Adds a default handler, will be invoked if none handler matched given `angel.do` input command

* `handler` : async Function (input: String)
